@@ -13,7 +13,7 @@ class Virus;
 template<typename TSeq>
 class Viruses;
 
-template<typename TSeq> 
+template<typename TSeq>
 class Viruses_const;
 
 template<typename TSeq>
@@ -69,7 +69,10 @@ inline std::function<void(size_t,Model<TSeq>*)> make_save_run(
     bool transmission = false,
     bool transition = false,
     bool reproductive = false,
-    bool generation = false
+    bool generation = false,
+    bool active_cases = false,
+    bool outbreak_size = false,
+    bool hospitalizations = false
     );
 
 // template<typename TSeq>
@@ -80,10 +83,10 @@ inline std::function<void(size_t,Model<TSeq>*)> make_save_run(
 
 /**
  * @brief Core class of epiworld.
- * 
+ *
  * The model class provides the wrapper that puts together `Agent`, `Virus`, and
  * `Tools`.
- * 
+ *
  * @tparam TSeq Type of sequence. In principle, users can build models in which
  * virus and human sequence is represented as numeric vectors (if needed.)
  */
@@ -106,7 +109,7 @@ protected:
 
     /**
      * @name Auxiliary variables for AgentsSample<TSeq> iterators
-     * 
+     *
      * @details These variables+objects are used by the AgentsSample<TSeq>
      * class for building efficient iterators over agents. The idea is to
      * reduce the memory allocation, so only during the first call of
@@ -121,11 +124,11 @@ protected:
 
     /**
      * @name Agents features
-     * 
+     *
      * @details Optionally, a model can include an external data source
      * pointing to agents information. The data can then be access through
      * the `Agent::operator()` method.
-     * 
+     *
      */
     ///@{
     double * agents_data = nullptr;
@@ -133,15 +136,15 @@ protected:
     ///@}
 
     bool directed = false;
-    
+
     std::vector< VirusPtr<TSeq> > viruses = {};
     std::vector< ToolPtr<TSeq> > tools = {};
 
-    std::vector< Entity<TSeq> > entities = {}; 
+    std::vector< Entity<TSeq> > entities = {};
     std::vector< Entity<TSeq> > entities_backup = {};
 
     std::shared_ptr< std::mt19937 > engine = std::make_shared< std::mt19937 >();
-    
+
     std::uniform_real_distribution<> runifd      =
         std::uniform_real_distribution<> (0.0, 1.0);
     std::normal_distribution<>       rnormd      =
@@ -163,20 +166,20 @@ protected:
 
     std::function<void(std::vector<Agent<TSeq>>*,Model<TSeq>*,epiworld_double)> rewire_fun;
     epiworld_double rewire_prop = 0.0;
-        
+
     std::map<std::string, epiworld_double > parameters;
     epiworld_fast_uint ndays = 0;
     Progress pb;
 
     std::vector< UpdateFun<TSeq> >    state_fun = {};                  ///< Functions to update states
     std::vector< std::string >        states_labels = {};              ///< Labels of the states
-    
+
     /** Function to distribute states. Goes along with the function  */
     std::function<void(Model<TSeq>*)> initial_states_fun = [](Model<TSeq> * /**/)
     -> void {};
 
     epiworld_fast_uint nstates = 0u;
-    
+
     bool verbose     = true;
     int current_date = 0;
 
@@ -188,7 +191,7 @@ protected:
     std::chrono::time_point<std::chrono::steady_clock> time_end;
 
     // std::chrono::milliseconds
-    std::chrono::duration<epiworld_double,std::micro> time_elapsed = 
+    std::chrono::duration<epiworld_double,std::micro> time_elapsed =
         std::chrono::duration<epiworld_double,std::micro>::zero();
     epiworld_fast_uint n_replicates = 0u;
     void chrono_start();
@@ -208,7 +211,7 @@ protected:
 
     /**
      * @brief Construct a new Event object
-     * 
+     *
      * @param agent_ Agent over which the action will be called
      * @param virus_ Virus pointer included in the action
      * @param tool_ Tool pointer included in the action
@@ -233,12 +236,12 @@ protected:
 
     /**
      * @name Tool Mixers
-     * 
+     *
      * These functions combine the effects tools have to deliver
      * a single effect. For example, wearing a mask, been vaccinated,
      * and the immune system combine together to jointly reduce
      * the susceptibility for a given virus.
-     * 
+     *
      */
     MixerFun<TSeq> susceptibility_reduction_mixer = susceptibility_reduction_mixer_default<TSeq>;
     MixerFun<TSeq> transmission_reduction_mixer = transmission_reduction_mixer_default<TSeq>;
@@ -247,14 +250,14 @@ protected:
 
     /**
      * @brief Advanced usage: Makes a copy of data and returns it as undeleted pointer
-     * 
-     * @param copy 
+     *
+     * @param copy
      */
     virtual Model<TSeq> * clone_ptr();
 
 public:
 
-    
+
     std::vector<epiworld_double> array_double_tmp;
     std::vector<Virus<TSeq> * > array_virus_tmp;
 
@@ -271,7 +274,7 @@ public:
      * @details `backup` can be used to restore the entire object
      * after a run. This can be useful if the user wishes to have
      * individuals start with the same network from the beginning.
-     * 
+     *
      */
     ///@{
     void set_backup();
@@ -286,7 +289,7 @@ public:
 
     /**
      * @name Random number generation
-     * 
+     *
      * @param eng Random number generator
      * @param s Seed
      */
@@ -325,9 +328,9 @@ public:
 
     /**
      * @name Add Virus/Tool to the model
-     * 
+     *
      * This is done before the model has been initialized.
-     * 
+     *
      * @param v Virus to be added
      * @param t Tool to be added
      * @param preval Initial prevalence (initial state.) It can be
@@ -345,16 +348,16 @@ public:
 
     /**
      * @brief Associate agents-entities from a file
-     * 
-     * The structure of the file should be two columns separated by 
+     *
+     * The structure of the file should be two columns separated by
      * space. The first column indexing between 0 and nagents-1, and the
      * second column between 0 and nentities - 1.
-     * 
+     *
      * @param fn Path to the file.
      * @param skip How many rows to skip.
      */
     void load_agents_entities_ties(std::string fn, int skip);
-    
+
     /**
      * @brief Associate agents-entities from data
     */
@@ -371,7 +374,7 @@ public:
 
     /**
      * @name Accessing population of the model
-     * 
+     *
      * @param fn std::string Filename of the edgelist file.
      * @param skip int Number of lines to skip in `fn`.
      * @param directed bool Whether the graph is directed or not.
@@ -422,12 +425,12 @@ public:
 
     /**
      * @name Functions to run the model
-     * 
+     *
      * @param seed Seed to be used for Pseudo-RNG.
      * @param ndays Number of days (steps) of the simulation.
      * @param fun In the case of `run_multiple`, a function that is called
      * after each experiment.
-     * 
+     *
      */
     ///@{
     void update_state();
@@ -452,6 +455,7 @@ public:
     size_t get_n_tools() const; ///< Number of tools in the model
     epiworld_fast_uint get_ndays() const;
     epiworld_fast_uint get_n_replicates() const;
+    size_t get_n_entities() const;
     void set_ndays(epiworld_fast_uint ndays);
     bool get_verbose() const;
     Model<TSeq> & verbose_off();
@@ -464,9 +468,9 @@ public:
      * @details This implementation assumes an undirected network,
      * thus if {(i,j), (k,l)} -> {(i,l), (k,j)}, the reciprocal
      * is also true, i.e., {(j,i), (l,k)} -> {(j,k), (l,i)}.
-     * 
+     *
      * @param proportion Proportion of ties to be rewired.
-     * 
+     *
      * @result A rewired version of the network.
      */
     ///@{
@@ -478,7 +482,7 @@ public:
 
     /**
      * @brief Wrapper of `DataBase::write_data`
-     * 
+     *
      * @param fn_virus_info Filename. Information about the virus.
      * @param fn_virus_hist Filename. History of the virus.
      * @param fn_tool_info Filename. Information about the tool.
@@ -487,6 +491,10 @@ public:
      * @param fn_transmission Filename. Transmission history.
      * @param fn_transition   Filename. Markov transition history.
      * @param fn_reproductive_number Filename. Case by case reproductive number
+     * @param fn_generation_time Filename. Generation time data.
+     * @param fn_active_cases Filename. Active cases data.
+     * @param fn_outbreak_size Filename. Outbreak size data.
+     * @param fn_hospitalizations Filename. Hospitalization data.
      */
     void write_data(
         std::string fn_virus_info,
@@ -497,16 +505,19 @@ public:
         std::string fn_transmission,
         std::string fn_transition,
         std::string fn_reproductive_number,
-        std::string fn_generation_time
+        std::string fn_generation_time,
+        std::string fn_active_cases,
+        std::string fn_outbreak_size,
+        std::string fn_hospitalizations
         ) const;
 
     /**
      * @name Export the network data in edgelist form
-     * 
+     *
      * @param fn std::string. File name.
      * @param source Integer vector
      * @param target Integer vector
-     * 
+     *
      * @details When passing the source and target, the function will
      * write the edgelist on those.
      */
@@ -525,44 +536,46 @@ public:
 
     /**
      * @brief Reset the model
-     * 
+     *
      * @details Resetting the model will:
      * - clear the database
      * - restore the population (if `set_backup()` was called before)
      * - re-distribute tools
      * - re-distribute viruses
      * - set the date to 0
-     * 
+     *
      */
     virtual void reset();
     const Model<TSeq> & print(bool lite = false) const;
 
     /**
      * @name Manage state (states) in the model
-     * 
+     *
      * @details
-     * 
-     * The functions `get_state` return the current values for the 
+     *
+     * The functions `get_state` return the current values for the
      * states included in the model.
-     * 
+     *
      * @param lab `std::string` Name of the state.
-     * 
-     * @return `add_state*` returns nothing.
-     * @return `get_state_*` returns a vector of pairs with the 
+     *
+     * @return `add_state*` returns the ID (index) of the registered state.
+     * @return `get_state_*` returns a vector of pairs with the
      * states and their labels.
      */
     ///@{
-    void add_state(std::string lab, UpdateFun<TSeq> fun = nullptr);
+    epiworld_fast_int state_of(std::string_view name);
+    epiworld_fast_int add_state(std::string lab, UpdateFun<TSeq> fun = nullptr);
     const std::vector< std::string > & get_states() const;
+    size_t get_n_states() const;
     const std::vector< UpdateFun<TSeq> > & get_state_fun() const;
     void print_state_codes() const;
     ///@}
 
     /**
      * @name Initial states
-     * 
+     *
      * @details These functions are called before the simulation starts.
-     * 
+     *
      * @param proportions_ Vector of proportions for each state.
      * @param queue_ Vector of queue for each state.
      */
@@ -573,7 +586,7 @@ public:
 
     /**
      * @name Setting and accessing parameters from the model
-     * 
+     *
      * @details Tools can incorporate parameters included in the model.
      * Internally, parameters in the tool are stored as pointers to
      * an std::map<> of parameters in the model. Using the `epiworld_fast_uint`
@@ -581,29 +594,29 @@ public:
      * added to the tool. Accessing parameters via the `std::string` method
      * involves searching the parameter directly in the std::map<> member
      * of the model (so it is not recommended.)
-     * 
+     *
      * The `par()` function members are aliases for `get_param()`.
-     * 
+     *
      * In the case of the function `read_params`, users can pass a file
      * listing parameters to be included in the model. Each line in the
      * file should have the following structure:
-     * 
+     *
      * ```
      * [name of parameter 1]: [value in double]
      * [name of parameter 2]: [value in double]
      * ...
      * ```
-     * 
+     *
      * The only condition for parameter names is that these do not include
      * a colon.
-     * 
-     * 
-     * @param initial_val 
+     *
+     *
+     * @param initial_val
      * @param pname Name of the parameter to add or to fetch
      * @param fn Path to the file containing parameters
      * @return The current value of the parameter
      * in the model.
-     * 
+     *
      */
     ///@{
     epiworld_double add_param(
@@ -628,7 +641,7 @@ public:
 
     /**
      * @name Set the user data object
-     * 
+     *
      * @param names string vector with the names of the variables.
      */
     ///[@
@@ -640,11 +653,11 @@ public:
 
     /**
      * @brief Set a global action
-     * 
+     *
      * @param fun A function to be called on the prescribed date
      * @param name Name of the action.
      * @param date Integer indicating when the function is called (see details)
-     * 
+     *
      * @details When date is less than zero, then the function is called
      * at the end of every day. Otherwise, the function will be called only
      * at the end of the indicated date.
@@ -672,9 +685,9 @@ public:
     /**
      * @name Queuing system
      * @details When queueing is on, the model will keep track of which agents
-     * are either in risk of exposure or exposed. This then is used at each 
+     * are either in risk of exposure or exposed. This then is used at each
      * step to act only on the aforementioned agents.
-     * 
+     *
      */
     ////@{
     void queuing_on(); ///< Activates the queuing system (default.)
@@ -685,9 +698,9 @@ public:
 
     /**
      * @name Get the susceptibility reduction object
-     * 
-     * @param v 
-     * @return epiworld_double 
+     *
+     * @param v
+     * @return epiworld_double
      */
     ///@{
     void set_susceptibility_reduction_mixer(MixerFun<TSeq> fun);
@@ -703,14 +716,14 @@ public:
 
     /**
      * @brief Set the agents data object
-     * 
+     *
      * @details The data should be an array with the data stored in a
      * column major order, i.e., by column.
-     * 
+     *
      * @param data_ Pointer to the first element of an array of size
      * `size() * ncols_`.
      * @param ncols_ Number of features included in the data.
-     * 
+     *
      */
     void set_agents_data(double * data_, size_t ncols_);
     double * get_agents_data();
@@ -718,8 +731,8 @@ public:
 
     /**
      * @brief Set the name object
-     * 
-     * @param name 
+     *
+     * @param name
      */
     void set_name(std::string name);
     std::string get_name() const;
@@ -729,7 +742,7 @@ public:
 
     /**
      * @brief Executes the stored action
-     * 
+     *
      * @param model_ Model over which it will be executed.
      */
     void events_run();
@@ -742,10 +755,61 @@ public:
      * @param self Whether to allow self-transitions.
      */
     void draw(
+        DiagramType diagram_type = DiagramType::Mermaid,
         const std::string & fn_output = "",
         bool self = false
     );
 
+    /**
+     * @brief Record a hospitalization event for an agent.
+     * 
+     * @param agent Reference to the agent being hospitalized.
+     * 
+     * @details
+     * This is a wrapper for `DataBase::record_hospitalization()`.
+     * For each hospitalization, the method records:
+     * - The current date from the model
+     * - The virus ID from the agent's virus
+     * - For each tool the agent has, a separate record with weight = 1/N
+     *   where N is the number of tools
+     * - If the agent has no tools, a single record with tool_id = -1 and
+     *   weight = 1.0
+     */
+    void record_hospitalization(Agent<TSeq> & agent);
+
+    /**
+     * @brief Get the full time series of hospitalization data.
+     * 
+     * @param date Output vector for dates.
+     * @param virus_id Output vector for virus IDs.
+     * @param tool_id Output vector for tool IDs.
+     * @param count Output vector for counts (number of hospitalized individuals).
+     * @param weight Output vector for summed weights (fractional contribution
+     *   based on tool distribution).
+     * 
+     * @details
+     * This is a wrapper for `DataBase::get_hospitalizations()`.
+     * Returns the full time series of hospitalization data. For each unique 
+     * (virus_id, tool_id) combination observed, returns an entry for every 
+     * day from 0 to ndays-1.
+     * 
+     * The `count` vector contains the actual number of individuals hospitalized 
+     * for that (date, virus_id, tool_id) combination. This is useful for 
+     * answering questions like "how many total people were hospitalized?" 
+     * regardless of their tools.
+     * 
+     * The `weight` vector contains fractional contributions: if an agent has N 
+     * tools, each tool gets weight = 1/N. Summing weights across all tool_ids 
+     * for a given date and virus_id gives the total number of hospitalizations.
+     */
+    void get_hospitalizations(
+        std::vector<int> & date,
+        std::vector<int> & virus_id,
+        std::vector<int> & tool_id,
+        std::vector<int> & count,
+        std::vector<double> & weight
+    ) const;
+
 
 };
 
