@@ -3,8 +3,12 @@
 
 /**
  * @brief Template for a Susceptible-Infected-Removed-Deceased (SIRD) model
+ * 
+ * ![Model Diagram](../assets/img/sird.png)
+ * 
+ * @ingroup death_compartmental
  */
-template<typename TSeq = int>
+template<typename TSeq = EPI_DEFAULT_TSEQ>
 class ModelSIRD : public epiworld::Model<TSeq>
 {
 public:
